@@ -1,5 +1,5 @@
 Description: fix FTBFS libmtd.h:288:8: error: unknown type name 'uint8_t' (Debian Bug 815735)
-Author: Martin Steigerwald <martin.steigerwald@teamix.de>
+Author: Martin Steigerwald <martin.steigerwald@proact.de>
 
 --- a/oslib/libmtd.h
 +++ b/oslib/libmtd.h
